package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.DemandReport;
import com.ruoyi.mall.domain.DemandReportDto;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-14
 */
public interface DemandReportMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public DemandReport selectDemandReportById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param demandReport 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<DemandReport> selectDemandReportList(DemandReport demandReport);

    /**
     * 新增【请填写功能名称】
     * 
     * @param demandReport 【请填写功能名称】
     * @return 结果
     */
    public int insertDemandReport(DemandReport demandReport);


    /**
     * 修改【请填写功能名称】
     * 
     * @param demandReport 【请填写功能名称】
     * @return 结果
     */
    public int updateDemandReport(DemandReport demandReport);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteDemandReportById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDemandReportByIds(Long[] ids);
}
